﻿using Microsoft.Kinect;
using System.Windows;
using System.Windows.Media;

namespace fedorax.KinectV2.Sample1
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {
        /// <summary>
        /// KinectSensorのインスタンス
        /// </summary>
        private KinectSensor sensor;

        /// <summary>
        /// コンストラクタ
        /// 
        /// Xamlから画面を生成し、Kinectの初期化とKinectの接続状態を確認します。
        /// また、このアプリが閉じられたときに、Kinectも停止させます。
        /// </summary>
        public MainWindow()
        {
            // Xamlの初期化処理
            InitializeComponent();

            try
            {
                // 初期化処理
                Init();

                // Kinectの接続確認
                CheckDevice();

                // アプリが停止した時にKinectも停止させる。
                this.Closing += (s, e) => { if (sensor == null) return; if (sensor.IsOpen) sensor.Close(); };
            }catch(System.Exception e)
            {
                MessageBox.Show("Kinect V2の初期化処理で致命的な例外が発生しました。\nKinectV2のSDKに含まれているKinect Configuration Veriferで確認してください。");
                this.Close();
            }
        }
        /// <summary>
        /// 初期化処理
        /// 
        /// Kinectのインスタンスを生成し、Kinectの開始処理とKinectの抜き差しイベントを定義します。
        /// </summary>
        private void Init()
        {
            // Kinectのインスタンスが未生成の時だけ実行する。
            if(sensor != null)
            {
                return;
            }
            // Kinect インスタンスの取得
            sensor = KinectSensor.GetDefault();
            // Kinectの開始
            sensor.Open();
            // Kinectの接続イベントをアタッチ
            sensor.IsAvailableChanged += sensor_IsAvailableChanged;
        }
        /// <summary>
        /// Kinect抜き差しイベント
        /// Kinectが抜かれた場合または、接続された場合に接続状態を確認します。
        /// </summary>
        /// <param name="sender">KinectSensor</param>
        /// <param name="e">IsAvailableChangedEventArgs</param>
        private void sensor_IsAvailableChanged(object sender, IsAvailableChangedEventArgs e)
        {
            // 接続状態を確認
            CheckDevice();
        }

        /// <summary>
        /// Kinectの確認
        /// 
        /// Kinectが接続されている場合、"Available"と表示します。
        /// Kinectが抜かれている場合、"Not Available"と表示します。
        /// また、Kinectが接続されていても、Kinectが開始できてない場合、"Not Available"と表示します。
        /// </summary>
        private void CheckDevice()
        {
            // 表示文字(Not Available)
            string device = "Not Available";
            // 表示色（赤)
            Brush color = new SolidColorBrush(Colors.Red);
            
            // Kinectが接続されている場合
            if (sensor.IsAvailable)
            {
                // 表示文字(Available)
                device = "Available";
                // 表示色(緑)
                color = new SolidColorBrush(Colors.Green);
            }
            // テキストブロックに表示文字を設定
            this.Device_Txt.Text = device;
            // テキストブロックに表示色を設定
            this.Device_Txt.Foreground = color;
        
        }
        

    }
}
